const path = require('path')
const { routes } = require('../src/routes')

const config = {
  projectName: 'miniapp',
  date: '2021-5-12',
  designWidth: 750,
  deviceRatio: {
    640: 2.34 / 2,
    750: 1,
    828: 1.81 / 2
  },
  sourceRoot: 'src',
  outputRoot: 'dist',
  plugins: [],
  defineConstants: {
  },
  alias: {
    '@/assets': path.resolve(__dirname, '..', 'src/assets'),
    '@/actions': path.resolve(__dirname, '..', 'src/actions'),
    '@/components': path.resolve(__dirname, '..', 'src/components'),
    '@/layout': path.resolve(__dirname, '..', 'src/layout'),
    '@/constants': path.resolve(__dirname, '..', 'src/constants'),
    '@/reducers': path.resolve(__dirname, '..', 'src/reducers'),
    '@/store': path.resolve(__dirname, '..', 'src/store'),
    '@/services': path.resolve(__dirname, '..', 'src/services'),
    '@/utils': path.resolve(__dirname, '..', 'src/utils'),
    '@/native': path.resolve(__dirname, '..', 'src/native'),
    '@/pages': path.resolve(__dirname, '..', 'src/pages'),
    '@/subpackages': path.resolve(__dirname, '..', 'src/subpackages'),
  },
  copy: {
    patterns: [
      // { from: 'src/native/', to: 'dist/native/' },
      // { from: 'src/subpackages/native/', to: 'dist/subpackages/native/' },
    ],
    options: {
    }
  },
  framework: 'react',
  mini: {
    // addChunkPages (pages) {
    //   // pages.set('subpackages/bar/index', ['subpackages/common'])
    //   routes.filter(r => r.pkg === 'subpackages').forEach((r) => {
    //     pages.set(r.pkg + '/' + r.page, ['subpackages/common'])
    //   })
    // },
    // webpackChain (chain) {
    //   chain.merge({
    //     optimization: {
    //       splitChunks: {
    //         cacheGroups: {
    //           subpackagesCommon: {
    //             name: 'subpackages/common',
    //             minChunks: 2,
    //             test: (module, chunks) => {
    //               const isNoOnlySubpackRequired = chunks.find(chunk => !(/\bsubpackages\b/.test(chunk.name)))
    //               return !isNoOnlySubpackRequired
    //             },
    //             priority: 200
    //           }
    //         }
    //       }
    //     }
    //   })
    // },
    compile: {
      // exclude: [
      //   path.resolve(__dirname, '..', 'src/native/')
      // ]
    },
    postcss: {
      pxtransform: {
        enable: true,
        config: {

        }
      },
      url: {
        enable: true,
        config: {
          limit: 1024 // 设定转换尺寸上限
        }
      },
      cssModules: {
        enable: false, // 默认为 false，如需使用 css modules 功能，则设为 true
        config: {
          namingPattern: 'module', // 转换模式，取值为 global/module
          generateScopedName: '[name]__[local]___[hash:base64:5]'
        }
      }
    }
  },
  h5: {
    publicPath: '/',
    staticDirectory: 'static',
    postcss: {
      autoprefixer: {
        enable: true,
        config: {
        }
      },
      cssModules: {
        enable: false, // 默认为 false，如需使用 css modules 功能，则设为 true
        config: {
          namingPattern: 'module', // 转换模式，取值为 global/module
          generateScopedName: '[name]__[local]___[hash:base64:5]'
        }
      }
    }
  }
}

module.exports = function (merge) {
  if (process.env.NODE_ENV === 'development') {
    return merge({}, config, require('./dev'))
  }
  return merge({}, config, require('./prod'))
}
