import React, { useState, useEffect } from "react";
import Taro from "@tarojs/taro";
import withLayout from "@/layout";
import "./index.scss";
import { ScrollView, Image, RichText,WebView } from "@tarojs/components";
import "@/assets/css/iconfont.css";
import {
  addNewsUv,
  favorNews,
  // addNewsShareNum,
  queryNewsDetail,
  cancelFavorNews,
} from "@/services/news";
import { formatDate } from "@/utils/chatDate";

export default withLayout((props) => {
  const { id } = props.router.params;

  const [data, setData] = useState(null);
  const [IsPull, setPull] = useState(false);
  const [PullTimer, setPullTimer] = useState(null);

  const PageRefresh = () => {
    // 页面下拉刷新回调
    setPull(true);
  };

  useEffect(() => {
    // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer);
      setPullTimer(
        setTimeout(() => {
          setPull(false);
        }, 2000)
      );
    }
  }, [IsPull]);

  const getData = (params) => {
    Taro.showLoading();
    queryNewsDetail(params).then((res) => {
  
      setData(res);
      Taro.hideLoading();
    });
  };

  useEffect(() => {
    if (id) {
      getData(id);
    }
  }, [id]);

  return (
    <view className="Page newsDetail flex-v">
      {data&& (data.newsDetailType === '0' ? <WebView src={data.newsDetail} /> :<>
        <view className="flex-item">
          <view>
            <ScrollView
              scroll-y={true}
              refresher-enabled={true}
              refresher-triggered={IsPull}
              onrefresherrefresh={PageRefresh}
              refresher-background="#fff"
            >
              <view className="PageContent">
                <view className="Info">
                  <view>
                    <text className="Title">{data.newsName}</text>
                    <view>
                      <text>阅读：{data.pvNum || 0}</text>
                      <text>点赞{data.favorNum || 0}</text>
                      <text>收藏{data.saveNum || 0}</text>
                    </view>
                    <text className="Time">
                      {`时间：${formatDate(data.createDate, "yyyy-M-d")} `}
                    </text>
                    <text className="Share">分享好友</text>
                  </view>
                </view>

                <view className="Content">
                  <RichText nodes={data.newsDetail}></RichText>
                </view>
              </view>
            </ScrollView>
          </view>
        </view>
        <view className="Bottom">
          <view>
            <Image
              mode="heightFix"
              src={require("@/assets/buildingDetail-icon3.png")}
            ></Image>
            <text>生成海报</text>
          </view>
          <view>
            <text className="iconfont icon-shoucang"></text>
            <text>收藏</text>
          </view>
        </view>
      </>)}
    </view>
  );
});
